/* © 2024 Appstock */

#import <Foundation/Foundation.h>
#import "IntegrationCaseManager.h"

#import "AppstockBannerAdViewController.h"
#import "AppstockVideoAdViewController.h"
#import "AppstockBannerInterstitialViewController.h"
#import "AppstockVideoInterstitialViewController.h"
#import "AppstockNativeViewController.h"

#import "AdMobBannerAdViewController.h"
#import "AdMobVideoAdViewController.h"
#import "AdMobBannerInterstitialViewController.h"
#import "AdMobVideoInterstitialViewController.h"
#import "AdMobNativeViewController.h"

#import "AppLovinBannerAdViewController.h"
#import "AppLovinVideoAdViewController.h"
#import "AppLovinBannerInterstitialViewController.h"
#import "AppLovinVideoInterstitialViewController.h"
#import "AppLovinNativeViewController.h"

/**
    Integration case title template - [IntegrationKind] [IntegrationAdFormat]
    [IntegrationKind] - Appstock, AdMob, AppLovin
    [IntegrationAdFormat] - "Banner", "Video", "Banner Interstitial", "Video Interstitial", "Native"
 */

@implementation IntegrationCaseManager

+ (NSArray<IntegrationCase *> *)allCases {
    
    return
    [
        [NSArray alloc]
        initWithObjects:
            [
                [IntegrationCase alloc]
                initWithTitle:@"Appstock Banner Ad"
                integrationKind:IntegrationKindAppstock
                adFormat:IntegrationAdFormatBanner
                configurationClosure:^UIViewController *{
                    return [AppstockBannerAdViewController new];
                }
            ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"Appstock Video Ad"
            integrationKind:IntegrationKindAppstock
            adFormat:IntegrationAdFormatVideo
            configurationClosure:^UIViewController *{
                return [AppstockVideoAdViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"Appstock Banner Interstitial"
            integrationKind:IntegrationKindAppstock
            adFormat:IntegrationAdFormatBannerInterstitial
            configurationClosure:^UIViewController *{
                return [AppstockBannerInterstitialViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"Appstock Video Interstitial"
            integrationKind:IntegrationKindAppstock
            adFormat:IntegrationAdFormatVideoInterstitial
            configurationClosure:^UIViewController *{
                return [AppstockVideoInterstitialViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"Appstock Native"
            integrationKind:IntegrationKindAppstock
            adFormat:IntegrationAdFormatNative
            configurationClosure:^UIViewController *{
                return [AppstockNativeViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AdMob Banner Ad"
            integrationKind:IntegrationKindAdMob
            adFormat:IntegrationAdFormatBanner
            configurationClosure:^UIViewController *{
                return [AdMobBannerAdViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AdMob Video Ad"
            integrationKind:IntegrationKindAdMob
            adFormat:IntegrationAdFormatVideo
            configurationClosure:^UIViewController *{
                return [AdMobVideoAdViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AdMob Banner Interstitial"
            integrationKind:IntegrationKindAdMob
            adFormat:IntegrationAdFormatBannerInterstitial
            configurationClosure:^UIViewController *{
                return [AdMobBannerInterstitialViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AdMob Video Interstitial"
            integrationKind:IntegrationKindAdMob
            adFormat:IntegrationAdFormatVideoInterstitial
            configurationClosure:^UIViewController *{
                return [AdMobVideoInterstitialViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AdMob Native"
            integrationKind:IntegrationKindAdMob
            adFormat:IntegrationAdFormatNative
            configurationClosure:^UIViewController *{
                return [AdMobNativeViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AppLovin MAX Banner Ad"
            integrationKind:IntegrationKindAppLovin
            adFormat:IntegrationAdFormatBanner
            configurationClosure:^UIViewController *{
                return [AppLovinBannerAdViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AppLovin MAX Video Ad"
            integrationKind:IntegrationKindAppLovin
            adFormat:IntegrationAdFormatVideo
            configurationClosure:^UIViewController *{
                return [AppLovinVideoAdViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AppLovin MAX Banner Interstitial"
            integrationKind:IntegrationKindAppLovin
            adFormat:IntegrationAdFormatBannerInterstitial
            configurationClosure:^UIViewController *{
                return [AppLovinBannerInterstitialViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AppLovin MAX Video Interstitial"
            integrationKind:IntegrationKindAppLovin
            adFormat:IntegrationAdFormatVideoInterstitial
            configurationClosure:^UIViewController *{
                return [AppLovinVideoInterstitialViewController new];
            }
        ],
        
        [
            [IntegrationCase alloc]
            initWithTitle:@"AppLovin MAX Native"
            integrationKind:IntegrationKindAppLovin
            adFormat:IntegrationAdFormatNative
            configurationClosure:^UIViewController *{
                return [AppLovinNativeViewController new];
            }
        ],
        
        nil];
}

@end
